Description: just specify spec_helper.rb in parent directory
Author: Hideki Yamane <henrich@debian.org>

---
Origin: vendor
Forwarded: no
Last-Update: 2013-01-03

--- ruby-aruba-0.5.1.orig/spec/aruba/api_spec.rb
+++ ruby-aruba-0.5.1/spec/aruba/api_spec.rb
@@ -1,4 +1,4 @@
-require 'spec_helper'
+require './spec/spec_helper'
 
 describe Aruba::Api  do
 
